@@ -3,35 +3,6 @@
 
 """ Command line utilities.
 
-Basically, this module provides three features:
-
-1. ``@climain`` decorator for main function.
-2. ``cliconfig()`` function to load config file.
-3. ``clistream()`` to handle command line arguments of files.
-
-Basic script looks like::
-
-    #!/usr/bin/env python
-    # -*- coding: utf-8 -*-
-
-    from pprint import pprint
-
-    from clitool.cli import climain, cliconfig, clistream
-
-    def tsv(line):
-        return line.split('\t')
-
-    @climain
-    def main(config, output, **kwargs):
-        cfg = cliconfig(config)
-        cfg.get("YOUR_CONFIG_KEY")
-        data = []
-        clistream(data.append, tsv, **kwargs)
-        pprint(data, stream=output)
-
-    if __name__ == '__main__':
-        main()
-
 This module is also executable to create script boilerplate. ::
 
     $ python -m clitool.cli -o your-script.py
@@ -46,16 +17,14 @@ import argparse
 from functools import wraps
 
 from clitool import DEFAULT_ENCODING
-from clitool.config import ConfigLoader
-from clitool.processor import CliHandler, Streamer
 
 
 def base_parser():
     """ Create arguments parser with basic options and no help message.
 
     * -c, --config: load configuration file.
-    * -v, --verbose: set up logging verbosity.
-    * -q, --quiet: quiet logging.
+    * -v, --verbose: increase logging verbosity. `-v`, `-vv`, and `-vvv`.
+    * -q, --quiet: quiet logging except critical level.
     * -o, --output: output file. (default=sys.stdout)
     * --basedir: base directory. (default=os.getcwd)
     * --input-encoding: input data encoding. (default=utf-8)
@@ -63,7 +32,7 @@ def base_parser():
     * --processes: count of processes.
     * --chunksize: a number of chunks submitted to the process pool.
 
-    :rtype: ArgumentParser object
+    :rtype: :class:`argparse.ArgumentParser`
     """
     parser = argparse.ArgumentParser(add_help=False)
 
@@ -100,8 +69,8 @@ def base_parser():
     group = parser.add_mutually_exclusive_group()
 
     group.add_argument("-v", "--verbose", dest="verbose",
-                default=False, action="store_true",
-                help="set logging to verbose mode")
+                action="count", default=0,
+                help="increase logging verbosity")
 
     group.add_argument("-q", "--quiet", dest="quiet",
                 default=False, action="store_true",
@@ -113,14 +82,28 @@ def base_parser():
 def parse_arguments(**kwargs):
     """ Parse command line arguments after setting basic options.
     If successfully parsed, set logging verbosity.
+    This function accepts variable keyword arguments.
+    Their values are passed to :meth:`ArgumentParser.add_argument`.
+    If special keyword `flags` is given, it'll be converted as flag option.
 
-    Examples ::
+    Examples - multiple files including zero ::
 
-    cliargs = parse_arguments(files=dict(nargs='*'))
-    cliargs = parse_arguments(files=dict(nargs='1'))
-    cliargs = parse_arguments(mode=dict(flags=('-m', '--mode')))
+        cliargs = parse_arguments(files=dict(nargs='*'))
+        print(cliargs.files)
 
-    :param kwargs: keywords arguments to pass `add_argument` method.
+    Examples - only one file (but property is list of files) ::
+
+        cliargs = parse_arguments(files=dict(nargs=1))
+        print(cliargs.files)
+
+    Examples - mode switch of defined values ::
+
+        cliargs = parse_arguments(mode=dict(
+                    flags=('-m', '--mode'), required=True,
+                    choises=("A", "B", "C")))
+        print(cliargs.mode)
+
+    :param kwargs: keywords arguments to pass :meth:`add_argument` method.
     :rtype: NameSpace object
     """
     parser = argparse.ArgumentParser(parents=[base_parser(), ])
@@ -144,13 +127,19 @@ def parse_arguments(**kwargs):
         e = sys.exc_info()[1]
         parser.error("File not found: %s" % (e, ))
 
-    if args.verbose:
+    if args.quiet:
+        logging.basicConfig(level=logging.CRITICAL)
+    elif args.verbose >= 3:
         logging.basicConfig(level=logging.DEBUG)
         if args.processes:
             import multiprocessing.util
             multiprocessing.util.log_to_stderr(logging.DEBUG)
-    elif not args.quiet:
+    elif args.verbose >= 2:
         logging.basicConfig(level=logging.INFO)
+    elif args.verbose >= 1:
+        logging.basicConfig(level=logging.WARN)
+    else:
+        logging.basicConfig(level=logging.ERROR)
 
     return args
 
@@ -176,6 +165,11 @@ def climain(func):
 
 def cliconfig(fp, env=None):
     """ Load configuration data.
+    Given pointer is closed internally.
+    If ``None`` is given, force to exit.
+
+    More detailed information is available on underlying feature,
+    :mod:`clitool.config`.
 
     :param fp: opened file pointer of configuration
     :type fp: FileType
@@ -183,8 +177,11 @@ def cliconfig(fp, env=None):
     """
     if fp is None:
         raise SystemExit('No configuration file is given.')
+    from clitool.config import ConfigLoader
     loader = ConfigLoader(fp)
     cfg = loader.load(env)
+    if not fp.closed:
+        fp.close()
     if not cfg:
         logging.warn('Configuration may be empty.')
     return cfg
@@ -194,8 +191,12 @@ def clistream(reporter, *args, **kwargs):
     """ Handle stream data on command line interface,
     and returns statistics of success, error, and total amount.
 
+    More detailed information is available on underlying feature,
+    :mod:`clitool.processor`.
+
     :param Handler: Handler for file-like streams.
-    :type Handler: CliHandler which supports `handle` method.
+            (default: :class:`clitool.processor.CliHandler`)
+    :type Handler: object which supports `handle` method.
     :param reporter: callback to report processed value
     :type reporter: callable
     :param args: functions to parse each item in the stream.
@@ -208,6 +209,7 @@ def clistream(reporter, *args, **kwargs):
     processes = kwargs.get('processes')
     chunksize = kwargs.get('chunksize')
 
+    from clitool.processor import CliHandler, Streamer
     Handler = kwargs.get('Handler', CliHandler)
     s = Streamer(reporter, processes=processes, *args)
     handler = Handler(s)
