@@ -1,8 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-""" Configuration loader to support multi file types.
-Available file types are:
+""" Configuration loader to support multi file types along with environmental
+variable ``PYTHON_CLITOOL_ENV``. Default variable is
+:const:`clitool.DEFAULT_RUNNING_MODE` (``development``).
+
+Supported file types are:
 
 * ini/cfg
 * json
@@ -27,10 +30,10 @@ from clitool import RUNNING_MODE_ENVKEY, DEFAULT_RUNNING_MODE
 
 
 class ConfigLoader(object):
-    """ Multi file type support config loader.
-
+    """
     :param fp: file pointer to load
-    :param filetype: file type either of 'ini|cfg', 'json', or 'yml|yaml'.
+    :param filetype: either of 'ini|cfg', 'json', or 'yml|yaml' file.
+        If nothing specified, detect by file extension automatically.
     :type filetype: string
     """
 
@@ -73,8 +76,10 @@ class ConfigLoader(object):
 
     def load(self, env=None):
         """ Load a section values of given environment.
+        If nothing to specified, use environmental variable.
+        If unknown environment was specified, warn it on logger.
 
-        :param env: environment to load
+        :param env: environment key to load in a coercive manner
         :type env: string
         :rtype: dict
         """
