@@ -172,15 +172,22 @@ class Streamer(object):
             PROCESSING_SUCCESS: 0,
             PROCESSING_ERROR: 0
         }
-        rs = ifilter(lambda r: r, stream)
+
+        def skip_unless(r):
+            if r:
+                return r
+            stats[PROCESSING_SKIPPED] += 1
+            stats[PROCESSING_TOTAL] += 1
+
+        rs = ifilter(skip_unless, stream)
         if self.processes:
             pool = multiprocessing.Pool(processes=self.processes)
             for f in self.procedures:
-                rs = pool.imap_unordered(f, ifilter(lambda r: r, rs),
+                rs = pool.imap_unordered(f, ifilter(skip_unless, rs),
                         chunksize=chunksize)
         else:
             for f in self.procedures:
-                rs = imap(f, ifilter(lambda r: r, rs))
+                rs = imap(f, ifilter(skip_unless, rs))
         start = time.time()
         i = 0
         try:
